==> pywaterflood-0.3.0.tar.gz: pywaterflood-0.3.0/CONTRIBUTING.md <==
# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

## Types of Contributions

### Report Bugs

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation

You can never have enough documentation! Please feel free to contribute to any
part of the documentation, such as the official docs, docstrings, or even on the
web in blog posts, articles, and such.

### Submit Feedback

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that this is a volunteer-driven project, and that contributions are
  welcome :)

## Get Started!

Ready to contribute? Here's how to set up `pywaterflood` for local development.

1. Download a copy of `pywaterflood` locally.

   ```console
   git clone https://github.com/frank1010111/pywaterflood.git
   ```

2. Install `pywaterflood` in a virtual environment using `maturin`:

   ```console
   python -m venv venv
   source venv/bin/activate  # assuming linux, MacOS, or git-bash
   pip install maturin
   maturin develop
   ```

3. Use `git` (or similar) to create a branch for local development and make your
   changes:

   ```console
   git checkout -b name-of-your-bugfix-or-feature
   ```

4. When you're done making changes, check that your changes conform to any code
   formatting requirements and pass any tests.

5. Commit your changes and open a pull request.

## Pull Request Guidelines

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include additional tests if appropriate.
2. If the pull request adds functionality, the docs should be updated.
3. The pull request should work for all currently supported operating systems
   and versions of Python.

## Code of Conduct

Please note that the `pywaterflood` project is released with a Code of Conduct.
By contributing to this project you agree to abide by its terms.

==> pywaterflood-0.3.2rc1.tar.gz: pywaterflood-0.3.2rc1/CONTRIBUTING.md <==
# Contributing

Contributions are welcome, and they are greatly appreciated! Every little bit
helps, and credit will always be given.

## Types of Contributions

### Report Bugs

If you are reporting a bug, please include:

- Your operating system name and version.
- Any details about your local setup that might be helpful in troubleshooting.
- Detailed steps to reproduce the bug.

### Fix Bugs

Look through the GitHub issues for bugs. Anything tagged with "bug" and "help
wanted" is open to whoever wants to implement it.

### Implement Features

Look through the GitHub issues for features. Anything tagged with "enhancement"
and "help wanted" is open to whoever wants to implement it.

### Write Documentation

You can never have enough documentation! Please feel free to contribute to any
part of the documentation, such as the official docs, docstrings, or even on the
web in blog posts, articles, and such.

### Submit Feedback

If you are proposing a feature:

- Explain in detail how it would work.
- Keep the scope as narrow as possible, to make it easier to implement.
- Remember that this is a volunteer-driven project, and that contributions are
  welcome :)

## Get Started!

Ready to contribute? Here's how to set up `pywaterflood` for local development.

1. Download a copy of `pywaterflood` locally with [git](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git).

   ```console
   git clone https://github.com/frank1010111/pywaterflood.git
   ```

2. Install python3 and Rust if you haven't already.

   [Python install guide](https://docs.python-guide.org/starting/installation/)

   [Rust install guide](https://www.rust-lang.org/tools/install)

3. Install `pywaterflood` in a virtual environment using `maturin`:

   ```console
   python3 -m venv venv
   source venv/bin/activate  # assuming linux, MacOS, or git-bash
   pip install maturin
   maturin develop
   ```

4. Use `git` to create a branch for local development and make your
   changes:

   ```console
   git checkout -b name-of-your-bugfix-or-feature
   ```

5. When you're done making changes, check that your changes conform to any code
   formatting requirements and pass any tests.

   You can run the linting and tests with nox:

   ```console
   pip install nox
   nox
   ```

6. Commit your changes and open a pull request.

## Pull Request Guidelines

Before you submit a pull request, check that it meets these guidelines:

1. The pull request should include additional tests if appropriate.
2. If the pull request adds functionality, the docs should be updated.
3. The pull request should work for all currently supported operating systems
   and versions of Python.

## Code of Conduct

Please note that the `pywaterflood` project is released with a
[Code of Conduct](https://github.com/frank1010111/pywaterflood/blob/master/CONDUCT.md).
By contributing to this project you agree to abide by its terms.
